@@ -141,7 +141,7 @@ ArchiveDialog::ArchiveDialog(const Akonadi::ETMCalendar::Ptr &cal, Akonadi::Inci
     fileLayout->addWidget(l);
     mArchiveFile = new KUrlRequester(QUrl::fromLocalFile(KCalPrefs::instance()->mArchiveFile), topFrame);
     mArchiveFile->setMode(KFile::File);
-    mArchiveFile->setFilter(i18nc("@label filter for KUrlRequester", "*.ics|iCalendar Files"));
+    mArchiveFile->setNameFilter(i18nc("@label filter for KUrlRequester", "iCalendar Files (*.ics)"));
     mArchiveFile->setToolTip(i18nc("@info:tooltip", "Set the location of the archive"));
     mArchiveFile->setWhatsThis(i18nc("@info:whatsthis",
                                      "The path of the archive file. The events and to-dos will be appended "
@@ -239,7 +239,7 @@ void ArchiveDialog::slotUser1()
         // Get destination URL
         QUrl destUrl(mArchiveFile->url());
         if (!destUrl.isValid()) {
-            KMessageBox::sorry(this, i18nc("@info", "The archive file name is not valid."));
+            KMessageBox::error(this, i18nc("@info", "The archive file name is not valid."));
             return;
         }
         // Force filename to be ending with vCalendar extension
@@ -277,3 +277,5 @@ void ArchiveDialog::showWhatsThis()
         QWhatsThis::showText(QCursor::pos(), widget->whatsThis());
     }
 }
+
+#include "moc_archivedialog.cpp"
